==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-registry/nifi-registry-core/nifi-registry-web-api/src/main/java/org/apache/nifi/registry/web/mapper/UntrustedProxyExceptionMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.web.mapper;

import org.apache.commons.lang3.StringUtils;
import org.apache.nifi.registry.security.authorization.UntrustedProxyException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

/**
 * Maps an UntrustedProxyException to a FORBIDDEN response.
 */
@Component
@Provider
public class UntrustedProxyExceptionMapper implements ExceptionMapper<UntrustedProxyException> {

    private static Logger LOGGER = LoggerFactory.getLogger(UntrustedProxyException.class);

    @Override
    public Response toResponse(final UntrustedProxyException exception) {
        LOGGER.info("{}. Returning {} response.", exception, Response.Status.FORBIDDEN);
        LOGGER.debug(StringUtils.EMPTY, exception);

        return Response.status(Response.Status.FORBIDDEN)
                .entity(exception.getMessage())
                .type("text/plain")
                .build();
    }
}

==> nifi-2.7.2-source-release.zip: nifi-2.7.2/nifi-registry/nifi-registry-core/nifi-registry-web-api/src/main/java/org/apache/nifi/registry/web/mapper/UntrustedProxyExceptionMapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.registry.web.mapper;

import org.apache.commons.lang3.StringUtils;
import org.apache.nifi.registry.security.authorization.UntrustedProxyException;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Component;

import jakarta.ws.rs.core.Response;
import jakarta.ws.rs.ext.ExceptionMapper;
import jakarta.ws.rs.ext.Provider;

/**
 * Maps an UntrustedProxyException to a FORBIDDEN response.
 */
@Component
@Provider
public class UntrustedProxyExceptionMapper implements ExceptionMapper<UntrustedProxyException> {

    private static Logger LOGGER = LoggerFactory.getLogger(UntrustedProxyException.class);

    @Override
    public Response toResponse(final UntrustedProxyException exception) {
        LOGGER.info("{}. Returning {} response.", exception, Response.Status.FORBIDDEN);
        LOGGER.debug(StringUtils.EMPTY, exception);

        return Response.status(Response.Status.FORBIDDEN)
                .entity(exception.getMessage())
                .type("text/plain")
                .build();
    }
}
